@@ -355,7 +355,11 @@ class Media(ABC):
             _d = self._conv_data(_d)
             _group = {}
             if _d.get("release_date", None) is not None:
-                _group.update({"year": _d.get("release_date")[:4]})
+                try:
+                    _group.update(
+                        {"year": str(int(_d.get("release_date")[:4]))})
+                except:
+                    pass
             _tmdb_id = _d.get("id", None)
             if _tmdb_id is not None:
                 _d.update({"tmdb_id": _tmdb_id})
